@@ -23,7 +23,6 @@
 #include <QStandardPaths>
 
 #include <QDBusConnection>
-#include <QKeySequence>
 
 static bool checkPlatform(const QJsonObject &metadata, const QString &platformName)
 {
@@ -75,9 +74,6 @@ static KGlobalAccelInterface *loadPlugin(GlobalShortcutsRegistry *parent)
 
 GlobalShortcutsRegistry::GlobalShortcutsRegistry()
     : QObject()
-    , _active_keys()
-    , _active_sequence()
-    , _components()
     , _manager(loadPlugin(this))
     , _config(qEnvironmentVariableIsSet("KGLOBALACCEL_TEST_MODE") ? QString() : QStringLiteral("kglobalshortcutsrc"), KConfig::SimpleConfig)
 {
@@ -108,14 +104,22 @@ GlobalShortcutsRegistry::~GlobalShortcutsRegistry()
     _keys_count.clear();
 }
 
+static std::vector<KdeDGlobalAccel::Component *>::const_iterator findByName(const std::vector<KdeDGlobalAccel::Component *> &components, const QString &name)
+{
+    return std::find_if(components.cbegin(), components.cend(), [&name](const KdeDGlobalAccel::Component *comp) {
+        return comp->uniqueName() == name;
+    });
+}
+
 KdeDGlobalAccel::Component *GlobalShortcutsRegistry::addComponent(KdeDGlobalAccel::Component *component)
 {
-    if (_components.value(component->uniqueName())) {
-        Q_ASSERT_X(false, "GlobalShortcutsRegistry::addComponent", "component already registered?!?!");
-        return _components.value(component->uniqueName());
+    auto it = findByName(m_components, component->uniqueName());
+    if (it != m_components.cend()) {
+        Q_ASSERT_X(false, "GlobalShortcutsRegistry::addComponent", "component already registered");
+        return *it;
     }
 
-    _components.insert(component->uniqueName(), component);
+    m_components.push_back(component);
     QDBusConnection conn(QDBusConnection::sessionBus());
 
     conn.registerObject(component->dbusPath().path(), component, QDBusConnection::ExportScriptableContents);
@@ -124,22 +128,20 @@ KdeDGlobalAccel::Component *GlobalShortcutsRegistry::addComponent(KdeDGlobalAcce
 
 void GlobalShortcutsRegistry::activateShortcuts()
 {
-    for (KdeDGlobalAccel::Component *component : std::as_const(_components)) {
+    for (KdeDGlobalAccel::Component *component : m_components) {
         component->activateShortcuts();
     }
 }
 
-QList<KdeDGlobalAccel::Component *> GlobalShortcutsRegistry::allMainComponents() const
+const std::vector<KdeDGlobalAccel::Component *> &GlobalShortcutsRegistry::allMainComponents() const
 {
-    return _components.values();
+    return m_components;
 }
 
 void GlobalShortcutsRegistry::clear()
 {
-    for (KdeDGlobalAccel::Component *component : std::as_const(_components)) {
-        delete component;
-    }
-    _components.clear();
+    qDeleteAll(m_components);
+    m_components.clear();
 
     // The shortcuts should have deregistered themselves
     Q_ASSERT(_active_keys.isEmpty());
@@ -152,19 +154,20 @@ QDBusObjectPath GlobalShortcutsRegistry::dbusPath() const
 
 void GlobalShortcutsRegistry::deactivateShortcuts(bool temporarily)
 {
-    for (KdeDGlobalAccel::Component *component : std::as_const(_components)) {
+    for (KdeDGlobalAccel::Component *component : m_components) {
         component->deactivateShortcuts(temporarily);
     }
 }
 
 KdeDGlobalAccel::Component *GlobalShortcutsRegistry::getComponent(const QString &uniqueName)
 {
-    return _components.value(uniqueName);
+    auto it = findByName(m_components, uniqueName);
+    return it != m_components.cend() ? *it : nullptr;
 }
 
 GlobalShortcut *GlobalShortcutsRegistry::getShortcutByKey(const QKeySequence &key, KGlobalAccel::MatchType type) const
 {
-    for (KdeDGlobalAccel::Component *component : std::as_const(_components)) {
+    for (KdeDGlobalAccel::Component *component : m_components) {
         GlobalShortcut *rc = component->getShortcutByKey(key, type);
         if (rc) {
             return rc;
@@ -176,24 +179,20 @@ GlobalShortcut *GlobalShortcutsRegistry::getShortcutByKey(const QKeySequence &ke
 QList<GlobalShortcut *> GlobalShortcutsRegistry::getShortcutsByKey(const QKeySequence &key, KGlobalAccel::MatchType type) const
 {
     QList<GlobalShortcut *> rc;
-
-    for (KdeDGlobalAccel::Component *component : std::as_const(_components)) {
+    for (KdeDGlobalAccel::Component *component : m_components) {
         rc = component->getShortcutsByKey(key, type);
         if (!rc.isEmpty()) {
             return rc;
         }
     }
-    return rc;
+    return {};
 }
 
 bool GlobalShortcutsRegistry::isShortcutAvailable(const QKeySequence &shortcut, const QString &componentName, const QString &contextName) const
 {
-    for (KdeDGlobalAccel::Component *component : std::as_const(_components)) {
-        if (!component->isShortcutAvailable(shortcut, componentName, contextName)) {
-            return false;
-        }
-    }
-    return true;
+    return std::all_of(m_components.cbegin(), m_components.cend(), [&shortcut, &componentName, &contextName](const KdeDGlobalAccel::Component *component) {
+        return component->isShortcutAvailable(shortcut, componentName, contextName);
+    });
 }
 
 Q_GLOBAL_STATIC(GlobalShortcutsRegistry, _self)
@@ -371,7 +370,8 @@ void GlobalShortcutsRegistry::loadSettings()
         const QStringList patterns = {QStringLiteral("*.desktop")};
         const auto lstDesktopFiles = dir.entryList(patterns);
         for (const QString &desktopFile : lstDesktopFiles) {
-            if (_components.contains(desktopFile)) {
+            auto it = findByName(m_components, desktopFile);
+            if (it != m_components.cend()) {
                 continue;
             }
 
@@ -466,7 +466,14 @@ KdeDGlobalAccel::Component *GlobalShortcutsRegistry::takeComponent(KdeDGlobalAcc
 {
     QDBusConnection conn(QDBusConnection::sessionBus());
     conn.unregisterObject(component->dbusPath().path());
-    return _components.take(component->uniqueName());
+
+    KdeDGlobalAccel::Component *retComponent = nullptr;
+    auto it = findByName(m_components, component->uniqueName());
+    if (it != m_components.cend()) {
+        retComponent = *it;
+        m_components.erase(it);
+    }
+    return retComponent;
 }
 
 void GlobalShortcutsRegistry::ungrabKeys()
@@ -525,7 +532,7 @@ bool GlobalShortcutsRegistry::unregisterKey(const QKeySequence &key, GlobalShort
 
 void GlobalShortcutsRegistry::writeSettings() const
 {
-    const auto lst = GlobalShortcutsRegistry::self()->allMainComponents();
+    const auto &lst = GlobalShortcutsRegistry::self()->allMainComponents();
     for (const KdeDGlobalAccel::Component *component : lst) {
         KConfigGroup configGroup(&_config, component->uniqueName());
         if (component->allShortcuts().isEmpty()) {
